@@ -1,4 +1,4 @@
-# copyright 2003-2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-database.
@@ -41,10 +41,12 @@ __docformat__ = "restructuredtext en"
 import sys
 import threading
 import logging
-from datetime import datetime, time
+from datetime import datetime, time, date
+from warnings import warn
 
 from logilab.common.modutils import load_module_from_name
-from logilab.common.date import utcdatetime, utctime
+from logilab.common.date import todate, todatetime, utcdatetime, utctime
+from logilab.common.deprecation import deprecated
 
 _LOGGER = logging.getLogger('logilab.database')
 
@@ -126,6 +128,33 @@ def set_prefered_driver(driver, module, _drivers=_PREFERED_DRIVERS):
         modules.insert(0, module)
 
 
+# types converters #############################################################
+
+def convert_datetime(value):
+    # Note: use is __class__ since issubclass(datetime, date)
+    if type(value) is date:
+        value = todatetime(value)
+    return value
+
+def convert_date(value):
+    if isinstance(value, datetime):
+        value = todate(value)
+    return value
+
+def convert_tzdatetime(value):
+    # Note: use is __class__ since issubclass(datetime, date)
+    if type(value) is date:
+        value = todatetime(value)
+    elif getattr(value, 'tzinfo', None):
+        value = utcdatetime(value)
+    return value
+
+def convert_tztime(value):
+    if getattr(value, 'tzinfo', None):
+        value = utctime(value)
+    return value
+
+
 # unified db api ###############################################################
 
 class UnknownDriver(Exception):
@@ -476,10 +505,19 @@ class COUNT(AggrFunctionDescr):
     maxargs = 2
 
     def as_sql(self, backend, args):
-        if len(args) == 2 and args[1] == get_db_helper(backend).boolean_value(True):
+        if len(args) == 2:
+            # deprecated COUNT DISTINCT form, suppose 2nd argument is true
+            warn('[lgdb 1.10] use COUNTDISTINCT instead of COUNT(X, TRUE)',
+                 DeprecationWarning)
             return '%s(DISTINCT %s)' % (self.name, args[0])
         return '%s(%s)' % (self.name, args[0])
 
+class COUNTDISTINCT(AggrFunctionDescr):
+    rtype = 'Int'
+
+    def as_sql(self, backend, args):
+        return '%s(DISTINCT %s)' % (self.name, args[0])
+
 class AVG(AggrFunctionDescr):
     rtype = 'Float'
 
@@ -612,7 +650,7 @@ class _FunctionRegistry(object):
             pass
         assert isinstance(funcdef, FunctionDescr)
         funcname = funcname or funcdef.name
-        self.functions[funcname] = funcdef
+        self.functions[funcname.upper()] = funcdef
 
     def get_function(self, funcname):
         try:
@@ -636,7 +674,7 @@ SQL_FUNCTIONS_REGISTRY = _FunctionRegistry()
 
 for func_class in (
     # aggregate functions
-    MIN, MAX, SUM, COUNT, AVG,
+    MIN, MAX, SUM, COUNT, COUNTDISTINCT, AVG,
     # transformation functions
     ABS, RANDOM,
     UPPER, LOWER, SUBSTRING, LENGTH,
@@ -652,6 +690,7 @@ def register_function(funcdef):
     """register the function `funcdef` on supported backends"""
     SQL_FUNCTIONS_REGISTRY.register_function(funcdef)
 
+
 class _TypeMapping(dict):
     def __getitem__(self, key):
         try:
@@ -666,6 +705,7 @@ class _TypeMapping(dict):
     def copy(self):
         return _TypeMapping(dict.copy(self))
 
+
 class _GenericAdvFuncHelper(FTIndexerMixIn):
     """Generic helper, trying to provide generic way to implement
     specific functionalities from others DBMS
@@ -690,6 +730,15 @@ class _GenericAdvFuncHelper(FTIndexerMixIn):
         'Interval' : 'interval',
         })
 
+    TYPE_CONVERTERS = {
+        'Boolean': bool,
+        # XXX needed for sqlite but I don't think it is for other backends
+        'Datetime': convert_datetime,
+        'Date': convert_date,
+        'TZDatetime': convert_tzdatetime,
+        'TZTime': convert_tztime,
+        }
+
     # DBMS resources descriptors and accessors
     backend_name = None # overridden in subclasses ('postgres', 'sqlite', etc.)
     needs_from_clause = False
@@ -932,12 +981,6 @@ INSERT INTO %s VALUES (0);''' % (seq_name, seq_name)
         table_name = self.temporary_table_name(table_name)
         return "CREATE TEMPORARY TABLE %s (%s);" % (table_name, table_schema)
 
-    def boolean_value(self, value):
-        if value:
-            return 'TRUE'
-        else:
-            return 'FALSE'
-
     def binary_value(self, value):
         """convert a value to a python object known by the driver to
         be mapped to a binary column"""
@@ -1004,3 +1047,7 @@ INSERT INTO %s VALUES (0);''' % (seq_name, seq_name)
     def list_indices(self, cursor, table=None):
         """return the list of indices of a database, only for the given table if specified"""
         raise NotImplementedError('not supported by this DBMS')
+
+    @deprecated('[lgdb 1.10] deprecated method')
+    def boolean_value(self, value):
+        return int(bool(value))
