@@ -1,4 +1,4 @@
-# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-database.
@@ -128,7 +128,6 @@ db._PREFERED_DRIVERS['mysql'] = ['MySQLdb']#, 'pyMySQL.MySQL']
 db._ADAPTER_DIRECTORY['mysql'] = {'MySQLdb': _MySqlDBAdapter,
                          }
 
-
 class _MyAdvFuncHelper(db._GenericAdvFuncHelper):
     """MySQL helper, taking advantage of postgres SEQUENCE support
     """
@@ -144,6 +143,8 @@ class _MyAdvFuncHelper(db._GenericAdvFuncHelper):
     # don't use timestamp which is automatically updated on row update
     TYPE_MAPPING['Datetime'] = 'datetime'
 
+    TYPE_CONVERTERS = db._GenericAdvFuncHelper.TYPE_CONVERTERS.copy()
+
     def mycmd(self, cmd, dbhost, dbport, dbuser):
         cmd = [cmd]
         # XXX compress
@@ -227,12 +228,6 @@ class _MyAdvFuncHelper(db._GenericAdvFuncHelper):
         """pattern matching using regexp"""
         return "REGEXP %s" % pattern
 
-    def boolean_value(self, value):
-        if value:
-            return 1
-        else:
-            return 0
-
     def list_users(self, cursor):
         """return the list of existing database users"""
         # Host, Password
